Tests
=====

This project comes with unit tests to make sure the code is reliable. We welcome
test contributions from developers. Especially, the multitenancy support testing
is still in progress, so that needs a lot of work. 
